From 479f5f799523bffbcc83dff581a2299c047c6fff Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Sat, 31 Jul 2010 19:44:01 +0000
Subject: Trinity Qt initial conversion

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebindings@1157645 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 kjsembed/qtbindings/qpopupmenu_imp.cpp | 54 +++++++++++++++++-----------------
 1 file changed, 27 insertions(+), 27 deletions(-)

(limited to 'kjsembed/qtbindings/qpopupmenu_imp.cpp')

diff --git a/kjsembed/qtbindings/qpopupmenu_imp.cpp b/kjsembed/qtbindings/qpopupmenu_imp.cpp
index 14430351..7b652422 100644
--- a/kjsembed/qtbindings/qpopupmenu_imp.cpp
+++ b/kjsembed/qtbindings/qpopupmenu_imp.cpp
@@ -1,12 +1,12 @@
 
 
 
-#include <qcstring.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <qpalette.h>
-#include <qpixmap.h>
-#include <qfont.h>
+#include <tqcstring.h>
+#include <tqimage.h>
+#include <tqpainter.h>
+#include <tqpalette.h>
+#include <tqpixmap.h>
+#include <tqfont.h>
 
 #include <kjs/object.h>
 
@@ -15,7 +15,7 @@
 #include <kjsembed/jsopaqueproxy.h>
 #include <kjsembed/jsbinding.h>
 
-#include <qpopupmenu.h>
+#include <tqpopupmenu.h>
 #include "qpopupmenu_imp.h"
 
 /**
@@ -43,7 +43,7 @@ void QPopupMenuImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object
     };
 
     int idx = 0;
-    QCString lastName;
+    TQCString lastName;
 
     while( methods[idx].name ) {
         if ( lastName != methods[idx].name ) {
@@ -85,7 +85,7 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
     };
 
     int idx = 0;
-    QCString lastName;
+    TQCString lastName;
 
     while( methods[idx].name ) {
         if ( lastName != methods[idx].name ) {
@@ -98,25 +98,25 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
 }
 
 /**
  * Extract a QPopupMenu pointer from an Object.
  */
-QPopupMenu *QPopupMenuImp::toQPopupMenu( KJS::Object &self )
+TQPopupMenu *QPopupMenuImp::toQPopupMenu( KJS::Object &self )
 {
     JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
     if ( ob ) {
-        QObject *obj = ob->object();
+        TQObject *obj = ob->object();
 	if ( obj )
-           return dynamic_cast<QPopupMenu *>( obj );
+           return dynamic_cast<TQPopupMenu *>( obj );
     }
 
     JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
     if ( !op )
         return 0;
 
-    if ( op->typeName() != "QPopupMenu" )
+    if ( op->typeName() != "TQPopupMenu" )
         return 0;
 
-    return op->toNative<QPopupMenu>();
+    return op->toNative<TQPopupMenu>();
 }
 
 /**
@@ -134,7 +134,7 @@ KJS::Object QPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &arg
              break;
     }
 
-    QString msg = i18n("QPopupMenuCons has no constructor with id '%1'").arg(id);
+    TQString msg = i18n("QPopupMenuCons has no constructor with id '%1'").arg(id);
     return throwError(exec, msg,KJS::ReferenceError);
 }
 
@@ -142,17 +142,17 @@ KJS::Object QPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &arg
 KJS::Object QPopupMenuImp::QPopupMenu_1( KJS::ExecState *exec, const KJS::List &args )
 {
 
     // Unsupported parameter QWidget *
     return KJS::Object();
 
-    QWidget * arg0; // Dummy
+    TQWidget * arg0; // Dummy
 
     const char *arg1 = (args.size() >= 2) ? args[1].toString(exec).ascii() : 0;
 
 
     // We should now create an instance of the QPopupMenu object
 
-    QPopupMenu *ret = new QPopupMenu(
+    TQPopupMenu *ret = new TQPopupMenu(
 
           arg0,
           arg1 );
@@ -238,7 +238,7 @@ KJS::Value QPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const K
         break;
     }
 
-    QString msg = i18n( "QPopupMenuImp has no method with id '%1'" ).arg( id );
+    TQString msg = i18n( "QPopupMenuImp has no method with id '%1'" ).arg( id );
     return throwError(exec, msg,KJS::ReferenceError);
 }
 
@@ -246,7 +246,7 @@ KJS::Value QPopupMenuImp::call( KJS::ExecState *exec, KJS::Object &self, const K
 KJS::Value QPopupMenuImp::popup_3( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
 
-    QPoint arg0 = extractQPoint(exec, args, 0);
+    TQPoint arg0 = extractQPoint(exec, args, 0);
 
     int arg1 = extractInt(exec, args, 1);
 
@@ -291,7 +291,7 @@ KJS::Value QPopupMenuImp::isCheckable_6( KJS::ExecState *exec, KJS::Object &obj,
 KJS::Value QPopupMenuImp::setFont_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
 
-    QFont arg0 = extractQFont(exec, args, 0);
+    TQFont arg0 = extractQFont(exec, args, 0);
 
       instance->setFont(
        arg0 );
@@ -327,7 +327,7 @@ KJS::Value QPopupMenuImp::exec_10( KJS::ExecState *exec, KJS::Object &obj, const
 KJS::Value QPopupMenuImp::exec_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
 
-    QPoint arg0 = extractQPoint(exec, args, 0);
+    TQPoint arg0 = extractQPoint(exec, args, 0);
 
     int arg1 = extractInt(exec, args, 1);
 
@@ -352,7 +352,7 @@ KJS::Value QPopupMenuImp::setActiveItem_12( KJS::ExecState *exec, KJS::Object &o
 
 KJS::Value QPopupMenuImp::sizeHint_13( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
-    QSize ret;
+    TQSize ret;
       ret = instance->sizeHint(  );
 
        return convertToValue( exec, ret );
@@ -374,7 +374,7 @@ KJS::Value QPopupMenuImp::idAt_14( KJS::ExecState *exec, KJS::Object &obj, const
 KJS::Value QPopupMenuImp::idAt_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
 {
 
-    QPoint arg0 = extractQPoint(exec, args, 0);
+    TQPoint arg0 = extractQPoint(exec, args, 0);
 
       int ret;
       ret = instance->idAt(
@@ -422,7 +422,7 @@ KJS::Value QPopupMenuImp::itemGeometry_19( KJS::ExecState *exec, KJS::Object &ob
 {
 
     int arg0 = extractInt(exec, args, 0);
-        QRect ret;
+        TQRect ret;
       ret = instance->itemGeometry(
        arg0 );
 
@@ -98,25 +98,25 @@ void QPopupMenuImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
 
 /**
- * Extract a QPopupMenu pointer from an Object.
+ * Extract a TQPopupMenu pointer from an Object.
  */
@@ -142,17 +142,17 @@ KJS::Object QPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &arg
 {
 
-    // Unsupported parameter QWidget *
+    // Unsupported parameter TQWidget *
     return KJS::Object();
 
@@ -142,17 +142,17 @@ KJS::Object QPopupMenuImp::construct( KJS::ExecState *exec, const KJS::List &arg
 
 
-    // We should now create an instance of the QPopupMenu object
+    // We should now create an instance of the TQPopupMenu object
 
-- 
cgit v1.2.1